catalog

package
v2.3.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 15, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package catalog is the single semantic index for the public Sonolus Go DSL.

Code generated by gencatalog; DO NOT EDIT.

Index

Constants

This section is empty.

Variables

var RuntimeFunctions = []resource.RuntimeFunction{}/* 191 elements not displayed */
var RuntimeSignatures = map[resource.RuntimeFunction]RuntimeSignature{}/* 176 elements not displayed */
var RuntimeSimulations = map[resource.RuntimeFunction]RuntimeSimulation{}/* 191 elements not displayed */
var Symbols = []Symbol{}/* 1158 elements not displayed */

Functions

func AllowsMode

func AllowsMode(symbol *Symbol, mode string) bool

func AllowsPhase

func AllowsPhase(symbol *Symbol, phase string) bool

func MemoryReadonly

func MemoryReadonly(currentMode mode.Mode, callback, storage string) bool

Types

type Effect

type Effect string
const (
	EffectPure  Effect = "pure"
	EffectRead  Effect = "read"
	EffectWrite Effect = "write"
)

type Kind

type Kind string
const (
	KindType     Kind = "type"
	KindFunction Kind = "function"
	KindMethod   Kind = "method"
	KindVariable Kind = "variable"
	KindConstant Kind = "constant"
	KindNative   Kind = "native"
	KindInternal Kind = "internal"
)

type Recipe

type Recipe struct {
	Kind      RecipeKind
	Runtime   resource.RuntimeFunction
	Prefix    []float64
	Operation string
	Reason    string
	Storage   string
	Offset    int
	Stride    int
	IndexArg  int
	Write     bool
}

func LookupRecipe

func LookupRecipe(symbol *Symbol) Recipe

LookupRecipe is the sole classification point for public DSL symbols. A forbidden recipe is deliberate and differs from a missing catalog symbol.

type RecipeKind

type RecipeKind string
const (
	RecipeRuntime     RecipeKind = "runtime"
	RecipeAggregate   RecipeKind = "aggregate"
	RecipeMemory      RecipeKind = "memory"
	RecipeResource    RecipeKind = "resource"
	RecipeContainer   RecipeKind = "container"
	RecipeCompileTime RecipeKind = "compile-time"
	RecipeForbidden   RecipeKind = "forbidden"
)

type RuntimeSignature

type RuntimeSignature struct {
	MinArgs, MaxArgs int
	ResultSlots      int
}

func LookupRuntimeSignature

func LookupRuntimeSignature(runtime resource.RuntimeFunction) (RuntimeSignature, bool)

type RuntimeSimulation

type RuntimeSimulation struct {
	Class        SimulationClass
	Signature    RuntimeSignature
	Effect       Effect
	Strategy     string
	SpecialShape bool
	Shape        string
	Arguments    string
}

func LookupRuntimeSimulation

func LookupRuntimeSimulation(runtime resource.RuntimeFunction) (RuntimeSimulation, bool)

type SimulationClass

type SimulationClass string
const (
	SimulationControl SimulationClass = "control"
	SimulationPure    SimulationClass = "pure"
	SimulationMemory  SimulationClass = "memory"
	SimulationRandom  SimulationClass = "random"
	SimulationEffect  SimulationClass = "effect"
	SimulationHandler SimulationClass = "handler"
)

type Symbol

type Symbol struct {
	Package   string
	Name      string
	Receiver  string
	Kind      Kind
	Signature string
	Modes     []string
	Phases    []string
	Effect    Effect
	Runtime   resource.RuntimeFunction
	Source    string
	Internal  bool
}

func LookupObject

func LookupObject(object types.Object) (*Symbol, bool)

func (Symbol) Key

func (s Symbol) Key() string

Directories

Path Synopsis
cmd
gencatalog command

Jump to